aboutsummaryrefslogtreecommitdiffstats
path: root/LUFA/Drivers/USB/Class/Host/StillImage.h
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2010-09-28 14:59:16 +0000
committerDean Camera <dean@fourwalledcubicle.com>2010-09-28 14:59:16 +0000
commitc0e4f52e8fecf74bc26ba813522aa96300bb844e (patch)
tree0736781b92fc6a781c4ffd693dc96634955c7093 /LUFA/Drivers/USB/Class/Host/StillImage.h
parent25d896a507d1895676dca19049a58ffc85384a0e (diff)
downloadlufa-c0e4f52e8fecf74bc26ba813522aa96300bb844e.tar.gz
lufa-c0e4f52e8fecf74bc26ba813522aa96300bb844e.tar.bz2
lufa-c0e4f52e8fecf74bc26ba813522aa96300bb844e.zip
Fix up incorrect version numbers in demo/project descriptors.
Add class name prefixes to missed constants in the class drivers to give all class driver elements a consistent namespace.
Diffstat (limited to 'LUFA/Drivers/USB/Class/Host/StillImage.h')
-rw-r--r--LUFA/Drivers/USB/Class/Host/StillImage.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/LUFA/Drivers/USB/Class/Host/StillImage.h b/LUFA/Drivers/USB/Class/Host/StillImage.h
index c215f1072..020f03003 100644
--- a/LUFA/Drivers/USB/Class/Host/StillImage.h
+++ b/LUFA/Drivers/USB/Class/Host/StillImage.h
@@ -115,7 +115,7 @@
/* Enums: */
/** Enum for the possible error codes returned by the \ref SI_Host_ConfigurePipes() function. */
- enum SIHost_EnumerationFailure_ErrorCodes_t
+ enum SI_Host_EnumerationFailure_ErrorCodes_t
{
SI_ENUMERROR_NoError = 0, /**< Configuration Descriptor was processed successfully. */
SI_ENUMERROR_InvalidConfigDescriptor = 1, /**< The device returned an invalid Configuration Descriptor. */
@@ -138,7 +138,7 @@
* \param[in] ConfigDescriptorSize Length of the attached device's Configuration Descriptor.
* \param[in] DeviceConfigDescriptor Pointer to a buffer containing the attached device's Configuration Descriptor.
*
* \return A value from the \ref SIHost_EnumerationFailure_ErrorCodes_t enum.
*/
uint8_t SI_Host_ConfigurePipes(USB_ClassInfo_SI_Host_t* const SIInterfaceInfo,
uint16_t ConfigDescriptorSize,
@@ -138,7 +138,7 @@
* \param[in] DeviceConfigDescriptor Pointer to a buffer containing the attached device's Configuration Descriptor.
*
- * \return A value from the \ref SIHost_EnumerationFailure_ErrorCodes_t enum.
+ * \return A value from the \ref SI_Host_EnumerationFailure_ErrorCodes_t enum.
*/
uint8_t SI_Host_ConfigurePipes(USB_ClassInfo_SI_Host_t* const SIInterfaceInfo,